@@ -652,6 +652,7 @@ static SEXP coercePairList(SEXP v, SEXPTYPE type)
     int i, n=0;
     SEXP rval= R_NilValue, vp, names;
 
+    if(type == LISTSXP) return v;/* IS pairlist */
     names = v;
     if (type == EXPRSXP) {
 	PROTECT(rval = allocVector(type, 1));
@@ -894,6 +895,7 @@ static SEXP asFunction(SEXP x)
 
 static SEXP ascommon(SEXP call, SEXP u, int type)
 {
+    /* coerce 'u' to 'type' : */
     SEXP  v;
 #ifdef OLD
     if (type == SYMSXP) {
